@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from wsgi import App, Request, Response
+from wsgi import App, Request, Response, redirect
 from config import cfg
 from exceptions import NotFound, Redirect, PermanentRedirect, BasicAuth
 from routing import urls, add_apps, add_urls, url4, auto_routing
