@@ -30,10 +30,12 @@ def render_to_string(fn, context):
             autoescape = True,
             cache_size = cfg.TEMPLATE_CACHE_SIZE,
             auto_reload = cfg.TEMPLATE_AUTO_RELOAD,
+            extensions = ['jinja2.ext.with_'],
         )        
         return _ENV.get_template(fn).render(context)
     
-def render_to_response(rq, fn, context, **response_kwargs):
+def render_to_response(rq, fn, context=None, **response_kwargs):
+    context = context or {}
     rq.context.update(context)
     return wsgi.Response(render_to_string(fn, rq.context), **response_kwargs)
     
